#Installation tasks

from java.lang import *
from java.io   import *
from java.util import *
from java.io   import BufferedReader, FileReader, File, FileInputStream
from java.lang import String, System

from com.axway.synchronyInstaller.engine import *
from com.axway.synchronyInstaller.util import *
from com.axway.synchronyInstaller.database import *
import synScript

class Script_taskCommon(synScript.SynScript):
    def __init__(self, installManager):
        synScript.SynScript.__init__(self, installManager)
        
        self.sep = SynFile.separator

    def getInstallationDir(self, component):
        return component.getInstallationDirectoryFullName()

    def getClientConfigurationDir(self, component):
        return component.getInstallationDirectoryFullName() + "extra" + self.sep + "aisclient-tools" + self.sep + "configuration"

    def updateDatastoreClientDBEntry(self, component, contextXmlFile, clientConfigDir):

        dbType = self.variableManager.getVariable("DB_TYPE")
        dbName = self.variableManager.getVariable("DB_NAME")
        dbHost = self.variableManager.getVariable("DB_HOST")
        dbPort = self.variableManager.getVariable("DB_PORT")
        
        dbAdminUser = ""
        dbAdminPassword = ""
        
        if self.variableManager.getVariable("USE_TWO_USERS")=="true":
            dbAdminUser = self.variableManager.getVariable("DB_ADMIN_USER")
            dbAdminPassword = self.variableManager.getVariable("DB_ADMIN_PWD")
            dbUser = self.variableManager.getVariable("DB_STANDARD_USER")
            dbPassword = self.variableManager.getVariable("DB_STANDARD_PWD")
            
        else:
            dbUser = self.variableManager.getVariable("DB_ADMIN_LOGIN")
            dbPassword = self.variableManager.getVariable("DB_ADMIN_PASSWORD")        
        
        if (dbType == SynSGBDManager.SGBD_Oracle11):
            #Oracle driver
            dbDriver = "oracle.jdbc.driver.OracleDriver"            
            #jdbc:oracle:thin:@<database_server_name>\:<database_port>\:<database_name>
            if SynSGBDManager.SGBD_URL_BASIC == self.getVar(SynSGBDManager.DB_URL_TYPE):
                if dbName is None or len(dbName.strip()) == 0:
                    dbName = self.variableManager.getVariable("DB_SERVICE_NAME")
                    dbUrl = "jdbc:oracle:thin:@//" + dbHost + ":" + dbPort + "/" + dbName
                else:
                    dbUrl = "jdbc:oracle:thin:@" + dbHost + ":" + dbPort + ":" + dbName            
            else:
                dbUrl = self.getVar(SynSGBDManager.DB_URL)
                dbName = "false"
        elif (dbType == SynSGBDManager.SGBD_SQLServer2000):
            #MS SQL Server driver
            dbDriver = "com.microsoft.sqlserver.jdbc.SQLServerDriver"
            #jdbc:sqlserver://<database_server_name>:<database_port>; databaseName=<database_name>
            dbUrl = "jdbc:sqlserver://" + dbHost + ":" + dbPort + "; databaseName=" + dbName
        else:
            #MySQL driver
            dbDriver = "com.mysql.jdbc.Driver"
            #jdbc:mysql://<database_server_name>:<database_port>/<database_name>
            dbUrl = "jdbc:mysql://" + dbHost + ":" + dbPort + "/" + dbName
            
        # Update the Datastore Client DB properties in context.xml file
        taskUpdateContextXml = SynJTaskXMLFile(contextXmlFile, "UTF-8")
        
        docBase = component.getInstallationDirectoryFullName() + "war"
        taskUpdateContextXml.modifyAttribute("Context", "docBase", docBase)
        
        taskUpdateContextXml.modifyAttribute("Context/Resource[@name=\"jdbc/ApplicationDataSource\"]", "driverClassName", dbDriver)
        taskUpdateContextXml.modifyAttribute("Context/Resource[@name=\"jdbc/ApplicationDataSource\"]", "url", dbUrl)
        taskUpdateContextXml.modifyAttribute("Context/Resource[@name=\"jdbc/ApplicationDataSource\"]", "username", dbUser)
        taskUpdateContextXml.modifyAttribute("Context/Resource[@name=\"jdbc/ApplicationDataSource\"]", "password", dbPassword)
        taskUpdateContextXml.setHidden()
        component.addTask("ConfigureDatastoreClient", "UpdateDatastoreClientDBInContextXmlFile", "Update Datastore Client DB in context.xml file", taskUpdateContextXml)
        
        # Update the Datastore Client DB properties in clientTools.properties file
        taskUpdatePropFile = SynJTaskPropertyFile(clientConfigDir + self.sep + "clientTools.properties")
        taskUpdatePropFile.updateProperty("DatastoreClientDBAdminUser", dbAdminUser, 1)
        taskUpdatePropFile.updateProperty("DatastoreClientDBAdminPassword", dbAdminPassword, 1)

        taskUpdatePropFile.updateProperty("DatastoreClientDBUser" , dbUser, 1)
        taskUpdatePropFile.updateProperty("DatastoreClientDBPassword" , dbPassword, 1)
        if (not dbName == "false"):
            taskUpdatePropFile.updateProperty("DatastoreClientDBName" , "jdbc" + "/" + dbName, 1)
        taskUpdatePropFile.updateProperty("DatastoreClientDBDriver", dbDriver, 1)
        taskUpdatePropFile.updateProperty("DatastoreClientDBUrl", dbUrl, 1)
        taskUpdatePropFile.setHidden()
        component.addTask("ConfigureDatastoreClient", "UpdateDatastoreClientDBInClientToolsPropertyFile", "Update Datastore Client DB in clientTools.properties file", taskUpdatePropFile)
        
        return None

    def createAISRepositoryDBEntry(self, component, contextXmlFile, clientConfigDir):
        
        dbUrl = self.variableManager.getVariable("Datastore", "AISRepositoryDBUrl")
        self.installManager.logDebug("URL in DatastoreClient: " + dbUrl)
        dbName = self.variableManager.getVariable("Datastore", "AISRepositoryDBName")
        dbUser = self.variableManager.getVariable("Datastore", "AISRepositoryDBUser")
        dbPassword = self.variableManager.getVariable("Datastore", "AISRepositoryDBPassword")
        dbDriver = self.variableManager.getVariable("Datastore", "AISRepositoryDBDriver")
        
        # Update the Repository DB properties in context.xml file
        taskUpdateContextXml = SynJTaskXMLFile(contextXmlFile, "UTF-8")
        taskUpdateContextXml.modifyAttribute("Context/Resource[@name=\"jdbc/ConfigurationDataSource\"]", "driverClassName", dbDriver)
        taskUpdateContextXml.modifyAttribute("Context/Resource[@name=\"jdbc/ConfigurationDataSource\"]", "url", dbUrl)
        taskUpdateContextXml.modifyAttribute("Context/Resource[@name=\"jdbc/ConfigurationDataSource\"]", "username", dbUser)
        taskUpdateContextXml.modifyAttribute("Context/Resource[@name=\"jdbc/ConfigurationDataSource\"]", "password", dbPassword)
        taskUpdateContextXml.setHidden()
        component.addTask("ConfigureDatastoreClient", "UpdateAISRepoDBInContextXmlFile", "Update Repository DB in context.xml file", taskUpdateContextXml)
        
        # Update the Repository DB properties in clientTools.properties file
        taskUpdatePropFile = SynJTaskPropertyFile(clientConfigDir + self.sep + "clientTools.properties")
        taskUpdatePropFile.updateProperty("AISRepoDBUser", dbUser, 1)
        taskUpdatePropFile.updateProperty("AISRepoDBPassword" , dbPassword, 1)
        taskUpdatePropFile.updateProperty("AISRepoDBDriver", dbDriver, 1)
        taskUpdatePropFile.updateProperty("AISRepoDBUrl", dbUrl, 1)
        taskUpdatePropFile.setHidden()
        component.addTask("ConfigureDatastoreClient", "UpdateAISRepoDBInClientToolsPropertyFile", "Update Repository DB in clientTools.properties file", taskUpdatePropFile)
        
        return None
        
    def updateAISRepositoryDBEntry(self, component, contextXmlFile, clientConfigDir):
        
        dbUrl = self.variableManager.getVariable("Datastore", "AISRepositoryDBUrl")
        self.installManager.logDebug("URL in DatastoreClient: " + dbUrl)
        dbName = self.variableManager.getVariable("Datastore", "AISRepositoryDBName")
        dbUser = self.variableManager.getVariable("Datastore", "AISRepositoryDBUser")
        dbPassword = self.variableManager.getVariable("Datastore", "AISRepositoryDBPassword")
        dbDriver = self.variableManager.getVariable("Datastore", "AISRepositoryDBDriver")
        
        # Update the Repository DB properties in context.xml file
        taskUpdateContextXml = SynJTaskXMLFile(contextXmlFile, "UTF-8")
        taskUpdateContextXml.modifyAttribute("Context/Resource[@name=\"jdbc/ConfigurationDataSource\"]", "driverClassName", dbDriver)
        taskUpdateContextXml.modifyAttribute("Context/Resource[@name=\"jdbc/ConfigurationDataSource\"]", "url", dbUrl)
        taskUpdateContextXml.modifyAttribute("Context/Resource[@name=\"jdbc/ConfigurationDataSource\"]", "username", dbUser)
        taskUpdateContextXml.modifyAttribute("Context/Resource[@name=\"jdbc/ConfigurationDataSource\"]", "password", dbPassword)
        taskUpdateContextXml.setHidden()
        component.addTask("ConfigureDatastoreClient", "UpdateAISRepoDBInContextXmlFile", "Update Repository DB in context.xml file", taskUpdateContextXml)
        
        # Update the Repository DB properties in clientTools.properties file
        taskUpdatePropFile = SynJTaskPropertyFile(clientConfigDir + self.sep + "clientTools.properties")
        taskUpdatePropFile.updateProperty("AISRepoDBUser", dbUser, 1)
        taskUpdatePropFile.updateProperty("AISRepoDBPassword" , dbPassword, 1)
        taskUpdatePropFile.updateProperty("AISRepoDBDriver", dbDriver, 1)
        taskUpdatePropFile.updateProperty("AISRepoDBUrl", dbUrl, 1)
        taskUpdatePropFile.setHidden()
        component.addTask("ConfigureDatastoreClient", "UpdateAISRepoDBInClientToolsPropertyFile", "Update Repository DB in clientTools.properties file", taskUpdatePropFile)
        
        return None

    def copyLog4jPropFile(self, component, contextXmlFile):

        task = SynJTaskMkdir(self.getInstallationDir(component) + "configuration")
        task.setHidden()
        component.addTask("ConfigureAISClient", "CreateConfigurationDirectory", self.getMes("Create configuration Directory"), task)
        
        # copy log4j.properties file from <INST_DIR>/war/WEB-INF//classes/log4j.properties to <INST_DIR>/log4j.properties 
        taskCreateFileScript = SynJTaskCopySingleFile(self.getInstallationDir(component) + "war" + self.sep + "WEB-INF" + self.sep + "classes" + self.sep + "log4j.properties", 
                                                self.getInstallationDir(component) + "configuration" + self.sep + "log4j.properties")
        taskCreateFileScript.setHidden()
        component.addTask("ConfigureAISClient", "CreateAuditLog4jPropsFile", self.getMes("synITPDCompDialog.CreateLogj4PropsFile"), taskCreateFileScript)
        
        # delete log4j.properties file from <INST_DIR>/war/META-INF/context.xml
        taskDeleteFileScript = SynJTaskDeleteSingleFile(self.getInstallationDir(component) + "war" + self.sep + "WEB-INF" + self.sep + "classes" + self.sep + "log4j.properties")
        taskDeleteFileScript.setHidden()
        component.addTask("ConfigureAISClient", "DeleteLog4jPropsFileFromWar", self.getMes("synITPDCompDialog.DeleteLog4jpropsFileFromWar"), taskDeleteFileScript)
        
        return None

    def updateWorkdirParametersInContext(self, component, contextXmlFile):
        workdirPath = self.getInstallationDir(component) + "extra" + self.sep + "work"
        task=SynJTaskXMLFile(contextXmlFile, "UTF-8")
        task.modifyAttribute("Context/Resource[@name=\"bean/ApplicationConfiguration\"]", "WorkDirectory", workdirPath)
        task.setHidden()
        component.addTask("ConfigureAISClient", "UpdateWorkdirPropFilePath", self.getMes("Set path to workdir properties file in context.xml"), task)
        
        return None

    def updateLogPropFilePathInContext(self, component, contextXmlFile):
        
        log4jFilePath = self.getInstallationDir(component) + "configuration" + self.sep + "log4j.properties"
        
        task=SynJTaskXMLFile(contextXmlFile, "UTF-8")
        task.modifyAttribute("Context/Resource[@name=\"bean/ApplicationConfiguration\"]", "Log4jFilePath", log4jFilePath)
        task.setHidden()
        component.addTask("ConfigureAISClient", "UpdateLogPropFilePath", self.getMes("Set path to logging properties file in context.xml"), task)
        
        return None
        
    def updateReportingParametersInContext(self, component, contextXmlFile):
        
        task=SynJTaskXMLFile(contextXmlFile, "UTF-8")
        server_use = self.variableManager.getVariable("SERVER_USE")
        isHTTPS = self.variableManager.getVariable("AISTools", "tomcatHTTPSEnabled")
        
        if(server_use == "aisTools_server" and isHTTPS == "true"):
            task.modifyAttribute("Context/Resource[@name=\"bean/ApplicationConfiguration\"]", "TrustStoreType", "jks")
            task.modifyAttribute("Context/Resource[@name=\"bean/ApplicationConfiguration\"]", "TrustStorePath", self.variableManager.getVariable("AISTools", "PassPortTruststoreFile"))
        else:
            task.modifyAttribute("Context/Resource[@name=\"bean/ApplicationConfiguration\"]", "TrustStoreType", "")
            task.modifyAttribute("Context/Resource[@name=\"bean/ApplicationConfiguration\"]", "TrustStorePath", "")
        
        task.setHidden()
        component.addTask("ConfigureAISClient", "UpdateReportingParameters", self.getMes("Set the reporting parameters in the context.xml"), task)
        
        return None
    
    def updateDocumentationPathInContext(self, component, contextXmlFile):
        
        task=SynJTaskXMLFile(contextXmlFile, "UTF-8")
        task.modifyAttribute("Context/Resource[@name=\"bean/ApplicationConfiguration\"]", "DocumentationPath", component.getParent().getInstallationDirectoryFullName() + "documentation")
        task.setHidden()
        component.addTask("ConfigureAISClient", "UpdateDocumentationPathParameter", self.getMes("Set the documentation path parameter in the context.xml"), task)
        
        return None

    #
    # Execute a script (used for import configurations)
    #
    def executeScript(self, component, osName, scriptName, argumentName, argumentValue):
        
        scriptInstallationPath = self.getInstallationDir(component) + "extra" + self.sep + "aisclient-tools" + self.sep + scriptName
        
        task = SynJTaskOSSpecificScript(osName, "", scriptInstallationPath, 1, File(self.getInstallationDir(component)))
        task.addArgument(argumentName)
        task.addArgument(argumentValue)
        task.setHidden()
        task.setIgnoreError()
        
        component.addTask(None, "ExecuteScriptCommand_" + argumentValue, "Execute Script command " + argumentValue, task)
        
        return None

    #
    # Execute external script
    #
    def executeExternalScript(self, component, osName, scriptFullName, argumentName, argumentValue, returnVariable):
        
        task = SynJTaskOSSpecificScript(osName, "", scriptFullName, 1, File(self.getInstallationDir(component)))
        task.addArgument(argumentName)
        task.addArgument(argumentValue)
        task.setHidden()
        task.setIgnoreError()
        task.setVariableWithReturnValue(returnVariable)
        
        component.addTask(None, "ExecuteScriptCommand_" + argumentValue, "Execute External Script command " + argumentValue, task)
        
        return None
    def isNoneEmptyOrBlankString (self, aString):
        if aString:
            if not aString.strip():
                return 1
        else:
            return 1
        return 0
class SynJTaskCheckScriptResult(SynJTask):
    def __init__(self, scriptName, returnVariableName, logFileName):
        self.scriptName = scriptName
        self.returnVariableName = returnVariableName
        self.logFileName = logFileName
    
    def execute(self, instmgr, comp):
        returnValue = instmgr.variableManager.getVariable(self.returnVariableName)
        instmgr.logDebug("Return value is: " + returnValue)
        if (returnValue <> "0"):
            instmgr.getVariableManager().addVariable(SynVariableManager.Variable_RootComponentName, SynScriptManager.DISPLAY_SUCCESS_WITH_WARNING_MSG, "true")
            instmgr.getVariableManager().getSynVariable(SynVariableManager.Variable_RootComponentName, SynScriptManager.DISPLAY_SUCCESS_WITH_WARNING_MSG).setSerialisable(0)
            warnMessage = "There was a problem running the script " + self.scriptName + ". Refer to " + self.logFileName + "  for more details."
            comp.addAdditionnalInformation(warnMessage)
            instmgr.logWarn(warnMessage)
        return 1         